
# Slot: uri


The uri that defines the possible values for the type definition

URI: [meta:type_uri](https://w3id.org/biolink/biolinkml/meta/type_uri)

## Domain and Range

[TypeDefinition](TypeDefinition.md) ->  <sub>OPT</sub> [Uriorcurie](Uriorcurie.md)

## Parents


## Children


## Used by

 * [TypeDefinition](TypeDefinition.md)
